<script setup lang="ts">
import TitlePanel from "@/views/ecg/doctor/components/TitlePanel.vue";
import QueuePanel from "@/views/ecg/doctor/components/QueuePanel.vue";
import {DoctorApi, PatientStatisticVO, RoomBedVO} from '@/api/ecg/doctor';
import {useUserStore} from "@/store/modules/user";
import {QueueVO} from "@/api/ecg/queue";
import {ElNotification} from "element-plus";
import DevRentPanel from "@/views/ecg/doctor/components/DevRentPanel.vue";

const userStore = useUserStore();

const roomBedVO: RoomBedVO = {
    roomId: null,
    roomName: null,
    bedNo: null
}

const onStagePatient = ref<QueueVO>({
  bedNo: "", bookCheckType: 0, bookTimeslot: 0, expired: 0, id: 0, jumpFlag: 0, passed: 0,
  patGender: 0, patId: "", patName: "", roomId: 0, roomName: "", seqNum: 0, status: 0
})

const patientStat = ref<PatientStatisticVO>({
    finishedNum: 0,
    readyNum: 0,
    passedNum: 0,
    queuingNum: 0
})

const state = ref<boolean>()

const patientList = ref<QueueVO[]>([])

let timerRunFlag : boolean = false
const bedControlFlag = ref<boolean>(true);
const finishFlag = ref<boolean>(true);
const passFlag = ref<boolean>(true);

const finishNextPatient = async () => {
  finishFlag.value = true
  try {
    patientList.value = await DoctorApi.finishNextPatient(roomBedVO)
    patientStat.value = await DoctorApi.getPatientStatistic(roomBedVO)
  } finally {
    finishFlag.value = false
  }
}

const passNextPatient = async () => {
  passFlag.value = true
  try {
    patientList.value = await DoctorApi.passNextPatient(roomBedVO)
    patientStat.value = await DoctorApi.getPatientStatistic(roomBedVO)
  } finally {
    passFlag.value = false
  }
}

const getOnstagePatient = () => {
  const tempPatient : QueueVO | undefined = patientList.value.find(item => item.status === 30)
  if (tempPatient !== undefined) {
    onStagePatient.value= tempPatient
    //onStagePatient.value.patName = tempPatient.patName
  }
}

const initLoad = async () => {
  if (roomBedVO.roomId == null) {
    ElNotification.error({
      message: '请重新就座!',
      type: 'info',
      duration: 3000 // 自动关闭时间，默认为3000ms
    })
    return
  }

  patientList.value = await DoctorApi.getPatientList(roomBedVO)
  getOnstagePatient()
  patientStat.value = await DoctorApi.getPatientStatistic(roomBedVO)
  const queueVO2 = await DoctorApi.bedDoctorGet(roomBedVO)
  if (queueVO2.status === 20)
    state.value = true
  else if (queueVO2.status === 30)
    state.value = false
}

const bedControl = async () => {
  bedControlFlag.value = true
  try {
    if (state.value) {
      await DoctorApi.bedDoctorPause(roomBedVO)
      state.value = false
    } else {
      await DoctorApi.bedDoctorResume(roomBedVO)
      state.value = true
    }
  } finally {
    bedControlFlag.value = false
  }
}

const doctorTimer = () => {
  console.log('doctorTimer ...')
  initLoad()
  if (timerRunFlag)
    setTimeout(doctorTimer, 5000) // five seconds
}

/** 初始化 **/
onMounted(() => {
  timerRunFlag = false
  bedControlFlag.value = true
  finishFlag.value = true
  passFlag.value = true

  if (userStore.isSetRoom) {
    roomBedVO.roomId = userStore.room!.roomId
    roomBedVO.roomName = userStore.room!.roomName
    roomBedVO.bedNo = userStore.room!.bedNo

    timerRunFlag = true
    doctorTimer()
  } else {
    roomBedVO.roomId = null
    roomBedVO.bedNo = null
  }

  bedControlFlag.value = false
  finishFlag.value = false
  passFlag.value = false
})

onUnmounted( () =>{
  timerRunFlag = false
})

const onEvent = () => {
  console.info("onDevRentPanelEvent...")
}

</script>

<template>
  <el-container>
    <el-header style="background-color: var(--el-color-primary-light-7); font-size: 24px">
      <TitlePanel :room="roomBedVO" :patientStatistic="patientStat" />
    </el-header>
    <el-container>
      <el-main>
        <DevRentPanel :patient="onStagePatient"  @success="onEvent"/>
      </el-main>
      <el-aside width="300px" style="background-color: var(--el-color-primary-light-7);">
        <QueuePanel :queue="patientList"/>
      </el-aside>
    </el-container>
    <el-container style="justify-content: center; margin-top: 30px">
      <el-button :disabled="finishFlag" type="primary" @click="finishNextPatient">叫号</el-button>
      <el-button :disabled="passFlag" type="primary" @click="passNextPatient">过号</el-button>
      <el-button :disabled="bedControlFlag" type="primary" @click="bedControl">{{state?'暂停':'恢复'}}</el-button>
    </el-container>
  </el-container>
</template>

<style scoped lang="scss">

</style>
